EXPORTS
	?CompareInputDataType@CCodecApiOpaqueData@@QAEHABVTDesC8@@@Z @ 1 NONAME ; int CCodecApiOpaqueData::CompareInputDataType(class TDesC8 const &)
	?CompareOutputDataType@CCodecApiOpaqueData@@QAEHABVTDesC8@@@Z @ 2 NONAME ; int CCodecApiOpaqueData::CompareOutputDataType(class TDesC8 const &)
	?ImplementationType@CCodecApiResolverData@@QBE?AVTUid@@XZ @ 3 NONAME ; class TUid CCodecApiResolverData::ImplementationType(void) const
	?InputDataFormat@CCodecApiResolverData@@QBE?BVTPtrC8@@XZ @ 4 NONAME ; class TPtrC8 const CCodecApiResolverData::InputDataFormat(void) const
	?InputDataType@CCodecApiOpaqueData@@QBEABVTDesC8@@XZ @ 5 NONAME ; class TDesC8 const & CCodecApiOpaqueData::InputDataType(void) const
	?Manufacturer@CCodecApiVideoOpaqueData@@QBEABVTDesC8@@XZ @ 6 NONAME ; class TDesC8 const & CCodecApiVideoOpaqueData::Manufacturer(void) const
	?MatchType@CCodecApiResolverData@@QBE?AW4TCodecApiResolverMatchType@@XZ @ 7 NONAME ; enum TCodecApiResolverMatchType CCodecApiResolverData::MatchType(void) const
	?MaxPictureRates@CCodecApiVideoOpaqueData@@QBEABV?$RArray@VTPictureRateAndSize@@@@XZ @ 8 NONAME ; class RArray<class TPictureRateAndSize> const & CCodecApiVideoOpaqueData::MaxPictureRates(void) const
	?MaxPictureSize@CCodecApiVideoOpaqueData@@QBEABVTSize@@XZ @ 9 NONAME ; class TSize const & CCodecApiVideoOpaqueData::MaxPictureSize(void) const
	?NewL@CCodecApiOpaqueData@@SAPAV1@ABVTDesC8@@@Z @ 10 NONAME ; class CCodecApiOpaqueData * CCodecApiOpaqueData::NewL(class TDesC8 const &)
	?NewL@CCodecApiResolverData@@SAPAV1@ABVTDesC8@@@Z @ 11 NONAME ; class CCodecApiResolverData * CCodecApiResolverData::NewL(class TDesC8 const &)
	?NewL@CCodecApiResolverData@@SAPAV1@XZ @ 12 NONAME ; class CCodecApiResolverData * CCodecApiResolverData::NewL(void)
	?NewL@CCodecApiVideoOpaqueData@@SAPAV1@ABVTDesC8@@@Z @ 13 NONAME ; class CCodecApiVideoOpaqueData * CCodecApiVideoOpaqueData::NewL(class TDesC8 const &)
	?NewLC@CCodecApiOpaqueData@@SAPAV1@ABVTDesC8@@@Z @ 14 NONAME ; class CCodecApiOpaqueData * CCodecApiOpaqueData::NewLC(class TDesC8 const &)
	?NewLC@CCodecApiResolverData@@SAPAV1@ABVTDesC8@@@Z @ 15 NONAME ; class CCodecApiResolverData * CCodecApiResolverData::NewLC(class TDesC8 const &)
	?NewLC@CCodecApiResolverData@@SAPAV1@XZ @ 16 NONAME ; class CCodecApiResolverData * CCodecApiResolverData::NewLC(void)
	?NewLC@CCodecApiVideoOpaqueData@@SAPAV1@ABVTDesC8@@@Z @ 17 NONAME ; class CCodecApiVideoOpaqueData * CCodecApiVideoOpaqueData::NewLC(class TDesC8 const &)
	?NewPackLC@CCodecApiResolverData@@QBEPAVHBufC8@@XZ @ 18 NONAME ; class HBufC8 * CCodecApiResolverData::NewPackLC(void) const
	?OutputDataFormat@CCodecApiResolverData@@QBE?BVTPtrC8@@XZ @ 19 NONAME ; class TPtrC8 const CCodecApiResolverData::OutputDataFormat(void) const
	?OutputDataType@CCodecApiOpaqueData@@QBEABVTDesC8@@XZ @ 20 NONAME ; class TDesC8 const & CCodecApiOpaqueData::OutputDataType(void) const
	?SetImplementationType@CCodecApiResolverData@@QAEXABVTUid@@@Z @ 21 NONAME ; void CCodecApiResolverData::SetImplementationType(class TUid const &)
	?SetInputDataL@CCodecApiResolverData@@QAEXABVTDesC8@@@Z @ 22 NONAME ; void CCodecApiResolverData::SetInputDataL(class TDesC8 const &)
	?SetMatchType@CCodecApiResolverData@@QAEXABW4TCodecApiResolverMatchType@@@Z @ 23 NONAME ; void CCodecApiResolverData::SetMatchType(enum TCodecApiResolverMatchType const &)
	?SetOutputDataL@CCodecApiResolverData@@QAEXABVTDesC8@@@Z @ 24 NONAME ; void CCodecApiResolverData::SetOutputDataL(class TDesC8 const &)
	?TypeUid@CCodecApiOpaqueData@@QBE?AVTUid@@XZ @ 25 NONAME ; class TUid CCodecApiOpaqueData::TypeUid(void) const
	?UnPackL@CCodecApiResolverData@@QAEXABVTDesC8@@@Z @ 26 NONAME ; void CCodecApiResolverData::UnPackL(class TDesC8 const &)

